summaryrefslogtreecommitdiffstats
path: root/dist
diff options
context:
space:
mode:
Diffstat (limited to 'dist')
-rwxr-xr-xdist/cache_name.txt2
-rwxr-xr-xdist/js/app.js4
-rwxr-xr-xdist/js/gsec.js2
-rwxr-xr-xdist/pages/about.html6
-rwxr-xr-xdist/sw.js4
5 files changed, 9 insertions, 9 deletions
diff --git a/dist/cache_name.txt b/dist/cache_name.txt
index cff4c21..3dbfd08 100755
--- a/dist/cache_name.txt
+++ b/dist/cache_name.txt
@@ -3,4 +3,4 @@
-///site-static-1.0.16.2-beta-90dfb78|||
+///site-static-1.0.16.3-beta-5376b61|||
diff --git a/dist/js/app.js b/dist/js/app.js
index 6d1226e..816250f 100755
--- a/dist/js/app.js
+++ b/dist/js/app.js
@@ -4,8 +4,8 @@
// @begin=js@
-const app_version = "1.0.16.2-beta";
-const previous_commit = "90dfb784cc11a8cc52e3cfb063273f44849f62a1";
+const app_version = "1.0.16.3-beta";
+const previous_commit = "5376b618e88d85b3fc16561176478c104af1a01b";
const BEZIAPP_UPDATE_INTERVAL = 300; // update vsakih 300 sekund
if ("serviceWorker" in navigator) {
diff --git a/dist/js/gsec.js b/dist/js/gsec.js
index 59d95bf..be98853 100755
--- a/dist/js/gsec.js
+++ b/dist/js/gsec.js
@@ -2,7 +2,7 @@
var gseAbsenceTypes=["notProcessed","authorizedAbsence","unauthorizedAbsence","doesNotCount"];function getStringBetween(string,start,end){return string.split(start).pop().split(end)[0];}
function stripHtml(html){var tmp=document.createElement("DIV");tmp.innerHTML=html;return tmp.textContent||tmp.innerText||"";}
function slDayToInt(inputString){let fourChars=inputString.substring(1,5);let fourCharDays=["oned","orek","reda","etrt","etek","obot","edel"];return fourCharDays.indexOf(fourChars);}
-const GSE_URL="https://zgimsis.gimb.tk/gse/";const GSEC_ERR_NET="GSEC NETWORK ERROR (ajax error)";const GSEC_ERR_NET_POSTBACK_GET="GSEC NETWORK ERROR (ajax error) in postback GET"
+const GSE_URL="https://zgimsis.gimb.tk/";const GSEC_ERR_NET="GSEC NETWORK ERROR (ajax error)";const GSEC_ERR_NET_POSTBACK_GET="GSEC NETWORK ERROR (ajax error) in postback GET"
const GSEC_ERR_NET_POSTBACK_POST="GSEC NETWORK ERROR (ajax error) in postback POST"
const GSEC_MSGTYPE_RECEIVED=0;const GSEC_MSGTYPE_SENT=1;const GSEC_MSGTYPE_DELETED=2;const GSEC_ERR_LOGIN="GSEC LOGIN ERROR";const GSEC_NO_ABSENCES="noAbsences";const GSEC_MSGTYPES=["msgReceived","msgSent","msgDeleted"];const GSEC_NORMAL_GRADE="GSEC NORMAL GRADE";const GSEC_ZAKLJUCNA_GRADE="GSEC ZAKLJUCNA GRADE";class gsec{constructor(){}
parseAndPost(inputHTML,params,formId=null,useDiffAction=null){return new Promise((resolve,reject)=>{let parser=new DOMParser();let parsed=parser.parseFromString(inputHTML,"text/html");var form;if(formId==null){form=parsed.getElementsByTagName("form")[0];}else{form=parsed.getElementById(formId);}
diff --git a/dist/pages/about.html b/dist/pages/about.html
index 6b0f39f..6653b09 100755
--- a/dist/pages/about.html
+++ b/dist/pages/about.html
@@ -79,7 +79,7 @@
<!-- One day in the future we may have sw cache version covered by this as well -->
<h5 class="subheader">
<x-su>version</x-su>
- 1.0.16.2-beta
+ 1.0.16.3-beta
</h5>
</div>
</div>
@@ -117,7 +117,7 @@
class="btn-floating btn-medium waves-effect waves-light button-theme-gimb" type="button">
<i class="material-icons">message</i>
</a>
- <a target="_blank" href="https://instagram.com/rstular/"
+ <a target="_blank" href="https://instagram.com/asijanec/"
class="btn-floating btn-medium waves-effect waves-light button-theme-gimb">
<i class="fab fa-instagram"></i>
</a>
@@ -163,7 +163,7 @@
<div class="row">
<p>
<small>
- ^HEAD 90dfb784cc11a8cc52e3cfb063273f44849f62a1
+ ^HEAD 5376b618e88d85b3fc16561176478c104af1a01b
</small>
</p>
</div>
diff --git a/dist/sw.js b/dist/sw.js
index 33eb888..73d5c5f 100755
--- a/dist/sw.js
+++ b/dist/sw.js
@@ -5,8 +5,8 @@
// @begin=js@
// Change version to cause cache refresh
-const static_cache_name = "site-static-1.0.16.2-beta-90dfb78";
-// commit before the latest is 90dfb784cc11a8cc52e3cfb063273f44849f62a1
+const static_cache_name = "site-static-1.0.16.3-beta-5376b61";
+// commit before the latest is 5376b618e88d85b3fc16561176478c104af1a01b
// Got them with find . -not -path '*/\.*' | sed "s/.*/\"&\",/" | grep -v sw.js
// sw.js NE SME BITI CACHAN, ker vsebuje verzijo!